"post a csv on google 💩"
from pathlib import Path

import typer
from gspread import authorize

from .tools import auth, write_in_sheet


app = typer.Typer()


@app.command()
def update(
    url: str = typer.Argument(None, envvar="GSP_URL"),
    token_path: Path = typer.Option(
        Path("~/.local/share/gsp/token.json").expanduser(), envvar="GSP_TOKEN_PATH"
    ),
    creds_path: Path = typer.Option(
        Path("~/.local/share/gsp/credentials.json").expanduser(),
        envvar="GSP_CREDENTIALS_PATH",
    ),
    sheet: int = typer.Option(0, envvar="GSP_SHEET", help="Index of the sheet to write"),
    line: int = typer.Option(1, envvar="GSP_LINE", help="Number of the line where writing starts"),
    col: int = typer.Option(1, envvar="GSP_COL", help="Number of the col where writing starts"),
) -> None:
    """Read a CSV on stdin and post it on an existing google 💩"""
    creds = auth(token_path, creds_path)
    client = authorize(creds)

    doc = client.open_by_url(url)
    write_in_sheet(doc, sheet, line, col)

    print(doc.url)


@app.command()
def create(
    title: str = typer.Argument("new sheet", envvar="GSP_TITLE"),
    token_path: Path = typer.Option(
        Path("~/.local/share/gsp/token.json").expanduser(), envvar="GSP_TOKEN_PATH"
    ),
    creds_path: Path = typer.Option(
        Path("~/.local/share/gsp/credentials.json").expanduser(),
        envvar="GSP_CREDENTIALS_PATH",
    ),
    sheet: int = typer.Option(0, envvar="GSP_SHEET", help="Index of the sheet to write"),
    line: int = typer.Option(1, envvar="GSP_LINE", help="Number of the line where writing starts"),
    col: int = typer.Option(1, envvar="GSP_COL", help="Number of the col where writing starts"),
) -> None:
    """Read a CSV on stdin and post a CSV on new google 💩"""
    creds = auth(token_path, creds_path)
    client = authorize(creds)

    doc = client.create(title)
    write_in_sheet(doc, sheet, line, col)

    print(doc.url)


if __name__ == "__main__":
    app()



import sys
from csv import reader
from pathlib import Path
from typing import Iterable, Iterator

from google.auth.transport.requests import Request
from google.oauth2.credentials import Credentials
from google_auth_oauthlib.flow import InstalledAppFlow
from gspread.cell import Cell
from gspread.spreadsheet import Spreadsheet


def iter_cell(
    value_iterator: Iterable[Iterable[str]], start_row: int, start_col: int
) -> Iterator[Cell]:
    for row, line in enumerate(value_iterator, start=start_row):
        for col, value in enumerate(line, start=start_col):
            yield Cell(row, col, value)


def auth(token_path: Path, creds_path: Path) -> Credentials:
    scopes = [
        "https://www.googleapis.com/auth/spreadsheets",
        "https://www.googleapis.com/auth/drive",
    ]

    if token_path.exists():
        creds = Credentials.from_authorized_user_file(token_path, scopes)

    if not creds or not creds.valid:
        if creds and creds.expired and creds.refresh_token:
            creds.refresh(Request())
        else:
            flow = InstalledAppFlow.from_client_secrets_file(creds_path, scopes)
            creds = flow.run_local_server(port=0)

        with token_path.open("w") as token:
            token.write(creds.to_json())

    return creds


def write_in_sheet(
    doc: Spreadsheet, sheet: int = 0, line: int = 1, col: int = 1
) -> None:
    """Write sheet content"""
    worksheet = doc.get_worksheet(sheet)
    csvreader = reader(iter(sys.stdin.readline, ""))

    worksheet.update_cells(tuple(iter_cell(csvreader, line, col)))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gsp']

package_data = \
{'': ['*']}

install_requires = \
['click==7.1.2',
 'google-auth>=2.6.2,<3.0.0',
 'gspread>=5.3.0,<6.0.0',
 'typer>=0.4.0,<0.5.0']

setup_kwargs = {
    'name': 'gsp',
    'version': '0.1.0',
    'description': 'Google Sheet Poster',
    'long_description': None,
    'author': 'juke',
    'author_email': 'juke@free.fr',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
